"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QBackingStore(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qbackingstore.html

    **Detailed Description**

    QBackingStore enables the use of **QPainter**  to paint on a **QWindow**
    with type RasterSurface. The other way of rendering to a **QWindow**  is
    through the use of OpenGL with **QOpenGLContext** .

    A QBackingStore contains a buffered representation of the window contents,
    and thus supports partial updates by using **QPainter**  to only update a
    sub region of the window contents.

    QBackingStore might be used by an application that wants to use **QPainter**
    without OpenGL acceleration and without the extra overhead of using the
    **QWidget**  or **QGraphicsView**  UI stacks. For an example of how to use
    QBackingStore see the **Raster Window Example** .
    """

    def __init__(self, window: "QWindow") -> None:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#QBackingStore

        **QBackingStore::QBackingStore(QWindow * window )**

        Constructs an empty surface for the given top-level **window**.
        """
        ...

    def hasStaticContents(self) -> bool:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#hasStaticContents

        **bool QBackingStore::hasStaticContents() const**

        Returns a boolean indicating if this window has static contents or not.
        """
        ...

    def staticContents(self) -> "QRegion":
        """
        https://doc.qt.io/qt-6/qbackingstore.html#staticContents

        **QRegion QBackingStore::staticContents() const**

        Returns a **QRegion**  representing the area of the window that has
        static contents.

        **See also** **setStaticContents** ().
        """
        ...

    def setStaticContents(self, region: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#setStaticContents

        **void QBackingStore::setStaticContents(const QRegion & region )**

        Set **region** as the static contents of this window.

        **See also** **staticContents** ().
        """
        ...

    def endPaint(self) -> None:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#endPaint

        **void QBackingStore::endPaint()**

        Ends painting.

        You should call this function after painting with the **paintDevice** ()
        has ended.

        **See also** **beginPaint** () and **paintDevice** ().
        """
        ...

    def beginPaint(self, a0: "QRegion") -> None:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#beginPaint

        **void QBackingStore::beginPaint(const QRegion & region )**

        Begins painting on the backing store surface in the given **region**.

        You should call this function before using the **paintDevice** () to
        paint.

        **See also** **endPaint** () and **paintDevice** ().
        """
        ...

    def scroll(self, area: "QRegion", dx: int, dy: int) -> bool:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#scroll

        **bool QBackingStore::scroll(const QRegion & area , int dx , int dy )**

        Scrolls the given **area** **dx** pixels to the right and **dy**
        downward; both **dx** and **dy** may be negative.

        Returns `true` if the area was scrolled successfully; false otherwise.
        """
        ...

    def size(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#size

        **QSize QBackingStore::size() const**

        Returns the current size of the window surface.
        """
        ...

    def resize(self, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#resize

        **void QBackingStore::resize(const QSize & size )**

        Sets the size of the window surface to **size**.

        **See also** **size** ().
        """
        ...

    def flush(
        self,
        region: "QRegion",
        window: typing.Optional["QWindow"] = ...,
        offset: QtCore.QPoint = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qbackingstore.html#flush

        **void QBackingStore::flush(const QRegion & region , QWindow * window =
        nullptr, const QPoint & offset = QPoint())**

        Flushes the given **region** from the specified **window** onto the
        screen.

        The **window** must either be the top level window represented by this
        backingstore, or a non-transient child of that window. Passing `nullptr`
        falls back to using the backingstore's top level window.

        If the **window** is a child window, the **region** should be in child
        window coordinates, and the **offset** should be the child window's
        offset in relation to the backingstore's top level window.

        You should call this function after ending painting with **endPaint**
        ().
        """
        ...

    def paintDevice(self) -> "QPaintDevice":
        """
        https://doc.qt.io/qt-6/qbackingstore.html#paintDevice

        **QPaintDevice *QBackingStore::paintDevice()**

        Returns the paint device for this surface.

        **Warning:** The device is only valid between calls to **beginPaint** ()
        and **endPaint** (). You should not cache the returned value.
        """
        ...

    def window(self) -> "QWindow":
        """
        https://doc.qt.io/qt-6/qbackingstore.html#window

        **QWindow *QBackingStore::window() const**

        Returns a pointer to the top-level window associated with this surface.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtCore import *


class QMimeData(QObject):
    """
    https://doc.qt.io/qt-6/qmimedata.html

    **Detailed Description**

    QMimeData is used to describe information that can be stored in the
    **clipboard** , and transferred via the **drag and drop**  mechanism.
    QMimeData objects associate the data that they hold with the corresponding
    MIME types to ensure that information can be safely transferred between
    applications, and copied around within the same application.

    QMimeData objects are usually created using `new` and supplied to **QDrag**
    or **QClipboard**  objects. This is to enable Qt to manage the memory that
    they use.

    A single QMimeData object can store the same data using several different
    formats at the same time. The **formats** () function returns a list of the
    available formats in order of preference. The **data** () function returns
    the raw data associated with a MIME type, and **setData** () allows you to
    set the data for a MIME type.

    For the most common MIME types, QMimeData provides convenience functions to
    access the data:

    TesterGetterSetterMIME Types
    **hasText** ()**text** ()**setText**
    ()`text/plain`
    **hasHtml** ()**html** ()**setHtml** ()`text/html`
    **hasUrls** ()**urls** ()**setUrls** ()`text/uri-list`
    **hasImage**
    ()**imageData** ()**setImageData** ()`image/` *
    **hasColor**
    ()**colorData** ()**setColorData** ()`application/x-color`

    For example, if your write a widget that accepts URL drags, you would end up
    writing code like this:

    void MyWidget::dragEnterEvent(**QDragEnterEvent**  *event)
        {
            if
    (event->mimeData()->hasUrls())
                event->acceptProposedAction();
    }

        void MyWidget::dropEvent(**QDropEvent**  *event)
        {
            if
    (event->mimeData()->hasUrls()) {
                foreach (**QUrl**  url,
    event->mimeData()->urls()) {
                    ...
                }
            }
    }

    There are three approaches for storing custom data in a QMimeData object:

    1. Custom data can be stored directly in a QMimeData object as a
    **QByteArray**  using **setData** (). For example:
    **QByteArray**  csvData = ...;

        **QMimeData**  *mimeData = new
    **QMimeData** ;
        mimeData->setData("text/csv", csvData);

      2. We can
    subclass QMimeData and reimplement **hasFormat** (), **formats** (), and
    **retrieveData** ().
      3. If the drag and drop operation occurs within a
    single application, we can subclass QMimeData and add extra data in it, and
    use a **qobject_cast** () in the receiver's drop event handler. For example:
    void MyWidget::dropEvent(**QDropEvent**  *event)
        {
            const
    MyMimeData *myData =
                    qobject_cast<const MyMimeData
    *>(event->mimeData());
            if (myData) {
                // access myData's
    data directly (not through QMimeData's API)
            }
        }

    **Platform-Specific MIME Types**

    On Windows, **formats** () will also return custom formats available in the
    MIME data, using the `x-qt-windows-mime` subtype to indicate that they
    represent data in non-standard formats. The formats will take the following
    form:

    application/x-qt-windows-mime;value="<custom type>"

    The following are examples of custom MIME types:

    application/x-qt-windows-mime;value="FileGroupDescriptor"
    application/x-qt-windows-mime;value="FileContents"

    The `value` declaration of each format describes the way in which the data
    is encoded.

    In some cases (e.g. dropping multiple email attachments), multiple data
    values are available. They can be accessed by adding an `index` value:

    application/x-qt-windows-mime;value="FileContents";index=0
    application/x-qt-windows-mime;value="FileContents";index=1

    On Windows, the MIME format does not always map directly to the clipboard
    formats. Qt provides QWinMime to map clipboard formats to open-standard MIME
    formats. Similarly, the QMacPasteboardMime maps MIME to Mac flavors.

    **See also** **QClipboard** , **QDragEnterEvent** , **QDragMoveEvent** ,
    **QDropEvent** , **QDrag** , and **Drag and Drop** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#QMimeData

        **QMimeData::QMimeData()**

        Constructs a new MIME data object with no data in it.
        """
        ...

    def retrieveData(self, mimetype: str, preferredType: QMetaType) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmimedata.html#retrieveData

        **[virtual protected] QVariant QMimeData::retrieveData(const QString &
        mimeType , QMetaType type ) const**

        Returns a variant with the given **type** containing data for the MIME
        type specified by **mimeType**. If the object does not support the MIME
        type or variant type given, a null variant is returned instead.

        This function is called by the general **data** () getter and by the
        convenience getters (**text** (), **html** (), **urls** (),
        **imageData** (), and **colorData** ()). You can reimplement it if you
        want to store your data using a custom data structure (instead of a
        **QByteArray** , which is what **setData** () provides). You would then
        also need to reimplement **hasFormat** () and **formats** ().

        **See also** **data** ().
        """
        ...

    def removeFormat(self, mimetype: str) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#removeFormat

        **void QMimeData::removeFormat(const QString & mimeType )**

        Removes the data entry for **mimeType** in the object.
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#clear

        **void QMimeData::clear()**

        Removes all the MIME type and data entries in the object.
        """
        ...

    def formats(self) -> typing.List[str]:
        """
        https://doc.qt.io/qt-6/qmimedata.html#formats

        **[virtual] QStringList QMimeData::formats() const**

        Returns a list of formats supported by the object. This is a list of
        MIME types for which the object can return suitable data. The formats in
        the list are in a priority order.

        For the most common types of data, you can call the higher-level
        functions **hasText** (), **hasHtml** (), **hasUrls** (), **hasImage**
        (), and **hasColor** () instead.

        **See also** **hasFormat** (), **setData** (), and **data** ().
        """
        ...

    def hasFormat(self, mimetype: str) -> bool:
        """
        https://doc.qt.io/qt-6/qmimedata.html#hasFormat

        **[virtual] bool QMimeData::hasFormat(const QString & mimeType ) const**

        Returns `true` if the object can return data for the MIME type specified
        by **mimeType** ; otherwise returns `false`.

        For the most common types of data, you can call the higher-level
        functions **hasText** (), **hasHtml** (), **hasUrls** (), **hasImage**
        (), and **hasColor** () instead.

        **See also** **formats** (), **setData** (), and **data** ().
        """
        ...

    def setData(self, mimetype: str, data: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#setData

        **void QMimeData::setData(const QString & mimeType , const QByteArray &
        data )**

        Sets the data associated with the MIME type given by **mimeType** to the
        specified **data**.

        For the most common types of data, you can call the higher-level
        functions **setText** (), **setHtml** (), **setUrls** (),
        **setImageData** (), and **setColorData** () instead.

        Note that if you want to use a custom data type in an item view drag and
        drop operation, you must register it as a Qt **meta type** , using the
        **Q_DECLARE_METATYPE** () macro, and implement stream operators for it.

        **See also** **data** (), **hasFormat** (), **QMetaType** , and
        **Q_DECLARE_METATYPE** ().
        """
        ...

    def data(self, mimetype: str) -> QByteArray:
        """
        https://doc.qt.io/qt-6/qmimedata.html#data

        **QByteArray QMimeData::data(const QString & mimeType ) const**

        Returns the data stored in the object in the format described by the
        MIME type specified by **mimeType**.

        **See also** **setData** ().
        """
        ...

    def hasColor(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmimedata.html#hasColor

        **bool QMimeData::hasColor() const**

        Returns `true` if the object can return a color (MIME type
        `application/x-color`); otherwise returns `false`.

        **See also** **setColorData** (), **colorData** (), and **hasFormat**
        ().
        """
        ...

    def setColorData(self, color: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#setColorData

        **void QMimeData::setColorData(const QVariant & color )**

        Sets the color data in the object to the given **color**.

        Colors correspond to the MIME type `application/x-color`.

        **See also** **colorData** (), **hasColor** (), and **setData** ().
        """
        ...

    def colorData(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmimedata.html#colorData

        **QVariant QMimeData::colorData() const**

        Returns a color if the data stored in the object represents a color
        (MIME type `application/x-color`); otherwise returns a null variant.

        A **QVariant**  is used because **QMimeData**  belongs to the Qt Core
        module, whereas **QColor**  belongs to Qt GUI. To convert the
        **QVariant**  to a **QColor** , simply use **qvariant_cast** (). For
        example:

        if (event->mimeData()->hasColor()) {
                **QColor**  color =
        qvariant_cast<**QColor** >(event->mimeData()->colorData());
                ...
        }

        **See also** **hasColor** (), **setColorData** (), and **data** ().
        """
        ...

    def hasImage(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmimedata.html#hasImage

        **bool QMimeData::hasImage() const**

        Returns `true` if the object can return an image; otherwise returns
        false.

        **See also** **setImageData** (), **imageData** (), and **hasFormat**
        ().
        """
        ...

    def setImageData(self, image: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#setImageData

        **void QMimeData::setImageData(const QVariant & image )**

        Sets the data in the object to the given **image**.

        A **QVariant**  is used because **QMimeData**  belongs to the Qt Core
        module, whereas **QImage**  belongs to Qt GUI. The conversion from
        **QImage**  to **QVariant**  is implicit. For example:

        mimeData->setImageData(**QImage** ("beautifulfjord.png"));

        **See also** **imageData** (), **hasImage** (), and **setData** ().
        """
        ...

    def imageData(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qmimedata.html#imageData

        **QVariant QMimeData::imageData() const**

        Returns a **QVariant**  storing a **QImage**  if the object can return
        an image; otherwise returns a null variant.

        A **QVariant**  is used because **QMimeData**  belongs to the Qt Core
        module, whereas **QImage**  belongs to Qt GUI. To convert the
        **QVariant**  to a **QImage** , simply use **qvariant_cast** (). For
        example:

        if (event->mimeData()->hasImage()) {
                **QImage**  image =
        qvariant_cast<**QImage** >(event->mimeData()->imageData());
                ...
        }

        **See also** **setImageData** () and **hasImage** ().
        """
        ...

    def hasHtml(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmimedata.html#hasHtml

        **bool QMimeData::hasHtml() const**

        Returns `true` if the object can return HTML (MIME type `text/html`);
        otherwise returns `false`.

        **See also** **setHtml** (), **html** (), and **hasFormat** ().
        """
        ...

    def setHtml(self, html: str) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#setHtml

        **void QMimeData::setHtml(const QString & html )**

        Sets **html** as the HTML (MIME type `text/html`) used to represent the
        data.

        **See also** **html** (), **hasHtml** (), **setText** (), and
        **setData** ().
        """
        ...

    def html(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimedata.html#html

        **QString QMimeData::html() const**

        Returns a string if the data stored in the object is HTML (MIME type
        `text/html`); otherwise returns an empty string.

        **See also** **setHtml** (), **hasHtml** (), and **setData** ().
        """
        ...

    def hasText(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmimedata.html#hasText

        **bool QMimeData::hasText() const**

        Returns `true` if the object can return plain text (MIME type
        `text/plain`); otherwise returns `false`.

        **See also** **setText** (), **text** (), **hasHtml** (), and
        **hasFormat** ().
        """
        ...

    def setText(self, text: str) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#setText

        **void QMimeData::setText(const QString & text )**

        Sets **text** as the plain text (MIME type `text/plain`) used to
        represent the data.

        **See also** **text** (), **hasText** (), **setHtml** (), and
        **setData** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qmimedata.html#text

        **QString QMimeData::text() const**

        Returns a plain text (MIME type `text/plain`) representation of the
        data.

        **See also** **setText** (), **hasText** (), **html** (), and **data**
        ().
        """
        ...

    def hasUrls(self) -> bool:
        """
        https://doc.qt.io/qt-6/qmimedata.html#hasUrls

        **bool QMimeData::hasUrls() const**

        Returns `true` if the object can return a list of urls; otherwise
        returns `false`.

        URLs correspond to the MIME type `text/uri-list`.

        **See also** **setUrls** (), **urls** (), and **hasFormat** ().
        """
        ...

    def setUrls(self, urls: typing.Iterable["QUrl"]) -> None:
        """
        https://doc.qt.io/qt-6/qmimedata.html#setUrls

        **void QMimeData::setUrls(const QList<QUrl> & urls )**

        Sets the URLs stored in the MIME data object to those specified by
        **urls**.

        URLs correspond to the MIME type `text/uri-list`.

        Since Qt 5.0, setUrls also exports the urls as plain text, if
        **setText**  was not called before, to make it possible to drop them
        into any lineedit and text editor.

        **See also** **urls** (), **hasUrls** (), and **setData** ().
        """
        ...

    def urls(self) -> typing.List["QUrl"]:
        """
        https://doc.qt.io/qt-6/qmimedata.html#urls

        **QList<QUrl> QMimeData::urls() const**

        Returns a list of URLs contained within the MIME data object.

        URLs correspond to the MIME type `text/uri-list`.

        **See also** **setUrls** (), **hasUrls** (), and **data** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QDataWidgetMapper(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qdatawidgetmapper.html

    **Detailed Description**

    QDataWidgetMapper can be used to create data-aware widgets by mapping them
    to sections of an item model. A section is a column of a model if the
    orientation is horizontal (the default), otherwise a row.

    Every time the current index changes, each widget is updated with data from
    the model via the property specified when its mapping was made. If the user
    edits the contents of a widget, the changes are read using the same property
    and written back to the model. By default, each widget's **user property**
    is used to transfer data between the model and the widget. Since Qt 4.3, an
    additional **addMapping** () function enables a named property to be used
    instead of the default user property.

    It is possible to set an item delegate to support custom widgets. By
    default, a **QItemDelegate**  is used to synchronize the model with the
    widgets.

    Let us assume that we have an item model named `model` with the following
    contents:

    1Qt NorwayOslo
    2Qt AustraliaBrisbane
    3Qt USAPalo Alto
    4Qt ChinaBeijing
    5Qt GermanyBerlin

    The following code will map the columns of the model to widgets called
    `mySpinBox`, `myLineEdit` and `myCountryChooser`:

    **QDataWidgetMapper**  *mapper = new **QDataWidgetMapper** ;
    mapper->setModel(model);
        mapper->addMapping(mySpinBox, 0);
    mapper->addMapping(myLineEdit, 1);
        mapper->addMapping(myCountryChooser,
    2);
        mapper->toFirst();

    After the call to **toFirst** (), `mySpinBox` displays the value `1`,
    `myLineEdit` displays `Qt Norway` and `myCountryChooser` displays `Oslo`.
    The navigational functions **toFirst** (), **toNext** (), **toPrevious** (),
    **toLast** () and **setCurrentIndex** () can be used to navigate in the
    model and update the widgets with contents from the model.

    The **setRootIndex** () function enables a particular item in a model to be
    specified as the root index - children of this item will be mapped to the
    relevant widgets in the user interface.

    QDataWidgetMapper supports two submit policies, `AutoSubmit` and
    `ManualSubmit`. `AutoSubmit` will update the model as soon as the current
    widget loses focus, `ManualSubmit` will not update the model unless
    **submit** () is called. `ManualSubmit` is useful when displaying a dialog
    that lets the user cancel all modifications. Also, other views that display
    the model won't update until the user finishes all their modifications and
    submits.

    Note that QDataWidgetMapper keeps track of external modifications. If the
    contents of the model are updated in another module of the application, the
    widgets are updated as well.

    **See also** **QAbstractItemModel**  and **QAbstractItemDelegate** .
    """

    class SubmitPolicy(enum.Enum):
        AutoSubmit: QDataWidgetMapper = ...
        ManualSubmit: QDataWidgetMapper = ...

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#QDataWidgetMapper

        **QDataWidgetMapper::QDataWidgetMapper(QObject * parent = nullptr)**

        Constructs a new QDataWidgetMapper with parent object **parent**. By
        default, the orientation is horizontal and the submit policy is
        `AutoSubmit`.

        **See also** **setOrientation** () and **setSubmitPolicy** ().
        """
        ...

    def toPrevious(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#toPrevious

        **[slot] void QDataWidgetMapper::toPrevious()**

        Populates the widgets with data from the previous row of the model if
        the orientation is horizontal (the default), otherwise with data from
        the previous column.

        Calls **setCurrentIndex** () internally. Does nothing if there is no
        previous row in the model.

        **See also** **toNext** () and **setCurrentIndex** ().
        """
        ...

    def toNext(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#toNext

        **[slot] void QDataWidgetMapper::toNext()**

        Populates the widgets with data from the next row of the model if the
        orientation is horizontal (the default), otherwise with data from the
        next column.

        Calls **setCurrentIndex** () internally. Does nothing if there is no
        next row in the model.

        **See also** **toPrevious** () and **setCurrentIndex** ().
        """
        ...

    def toLast(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#toLast

        **[slot] void QDataWidgetMapper::toLast()**

        Populates the widgets with data from the last row of the model if the
        orientation is horizontal (the default), otherwise with data from the
        last column.

        Calls **setCurrentIndex** () internally.

        **See also** **toFirst** () and **setCurrentIndex** ().
        """
        ...

    def toFirst(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#toFirst

        **[slot] void QDataWidgetMapper::toFirst()**

        Populates the widgets with data from the first row of the model if the
        orientation is horizontal (the default), otherwise with data from the
        first column.

        This is equivalent to calling `setCurrentIndex(0)`.

        **See also** **toLast** () and **setCurrentIndex** ().
        """
        ...

    def submit(self) -> bool:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#submit

        **[slot] bool QDataWidgetMapper::submit()**

        Submits all changes from the mapped widgets to the model.

        For every mapped section, the item delegate reads the current value from
        the widget and sets it in the model. Finally, the model's **submit** ()
        method is invoked.

        Returns `true` if all the values were submitted, otherwise false.

        Note: For database models, **QSqlQueryModel::lastError** () can be used
        to retrieve the last error.

        **See also** **revert** () and **setSubmitPolicy** ().
        """
        ...

    def setCurrentModelIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#setCurrentModelIndex

        **[slot] void QDataWidgetMapper::setCurrentModelIndex(const QModelIndex
        & index )**

        Sets the current index to the row of the **index** if the orientation is
        horizontal (the default), otherwise to the column of the **index**.

        Calls **setCurrentIndex** () internally. This convenience slot can be
        connected to the signal **currentRowChanged** () or
        **currentColumnChanged** () of another view's **selection model** .

        The following example illustrates how to update all widgets with new
        data whenever the selection of a **QTableView**  named `myTableView`
        changes:

        **QDataWidgetMapper**  *mapper = new **QDataWidgetMapper** ;
        connect(myTableView->selectionModel(), &**QItemSelectionModel**
        ::currentRowChanged,
                    mapper, &**QDataWidgetMapper**
        ::setCurrentModelIndex);

        **See also** **currentIndex** ().
        """
        ...

    def setCurrentIndex(self, index: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#currentIndex-prop

        **currentIndex : int**

        This property holds the current row or column

        The widgets are populated with with data from the row at **index** if
        the orientation is horizontal (the default), otherwise with data from
        the column at **index**.

        **Access functions:**

        int **currentIndex** () const
        virtual void **setCurrentIndex** (int
        **index** )

        **Notifier signal:**

        void ****currentIndexChanged** ** (int **index** )

        **See also** **setCurrentModelIndex** (), **toFirst** (), **toNext** (),
        **toPrevious** (), and **toLast** ().
        """
        ...

    def revert(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#revert

        **[slot] void QDataWidgetMapper::revert()**

        Repopulates all widgets with the current data of the model. All
        unsubmitted changes will be lost.

        **See also** **submit** () and **setSubmitPolicy** ().
        """
        ...

    def currentIndex(self) -> int:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#currentIndex-prop

        **currentIndex : int**

        This property holds the current row or column

        The widgets are populated with with data from the row at **index** if
        the orientation is horizontal (the default), otherwise with data from
        the column at **index**.

        **Access functions:**

        int **currentIndex** () const
        virtual void **setCurrentIndex** (int
        **index** )

        **Notifier signal:**

        void ****currentIndexChanged** ** (int **index** )

        **See also** **setCurrentModelIndex** (), **toFirst** (), **toNext** (),
        **toPrevious** (), and **toLast** ().
        """
        ...

    def clearMapping(self) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#clearMapping

        **void QDataWidgetMapper::clearMapping()**

        Clears all mappings.

        **See also** **addMapping** () and **removeMapping** ().
        """
        ...

    def mappedWidgetAt(self, section: int) -> QWidget:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#mappedWidgetAt

        **QWidget *QDataWidgetMapper::mappedWidgetAt(int section ) const**

        Returns the widget that is mapped at **section** , or 0 if no widget is
        mapped at that section.

        **See also** **addMapping** () and **removeMapping** ().
        """
        ...

    def mappedSection(self, widget: QWidget) -> int:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#mappedSection

        **int QDataWidgetMapper::mappedSection(QWidget * widget ) const**

        Returns the section the **widget** is mapped to or -1 if the widget is
        not mapped.

        **See also** **addMapping** () and **removeMapping** ().
        """
        ...

    def mappedPropertyName(self, widget: QWidget) -> QtCore.QByteArray:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#mappedPropertyName

        **QByteArray QDataWidgetMapper::mappedPropertyName(QWidget * widget )
        const**

        Returns the name of the property that is used when mapping data to the
        given **widget**.

        **See also** **mappedSection** (), **addMapping** (), and
        **removeMapping** ().
        """
        ...

    def removeMapping(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#removeMapping

        **void QDataWidgetMapper::removeMapping(QWidget * widget )**

        Removes the mapping for the given **widget**.

        **See also** **addMapping** () and **clearMapping** ().
        """
        ...

    @typing.overload
    def addMapping(self, widget: QWidget, section: int) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#addMapping

        **void QDataWidgetMapper::addMapping(QWidget * widget , int section )**

        Adds a mapping between a **widget** and a **section** from the model.
        The **section** is a column in the model if the orientation is
        horizontal (the default), otherwise a row.

        For the following example, we assume a model `myModel` that has two
        columns: the first one contains the names of people in a group, and the
        second column contains their ages. The first column is mapped to the
        **QLineEdit**  `nameLineEdit`, and the second is mapped to the
        **QSpinBox**  `ageSpinBox`:

        **QDataWidgetMapper**  *mapper = new **QDataWidgetMapper** ;
        mapper->setModel(myModel);
            mapper->addMapping(nameLineEdit, 0);
        mapper->addMapping(ageSpinBox, 1);

        **Notes:**

        * If the **widget** is already mapped to a section, the old mapping will
        be replaced by the new one.
          * Only one-to-one mappings between
        sections and widgets are allowed. It is not possible to map a single
        section to multiple widgets, or to map a single widget to multiple
        sections.

        **See also** **removeMapping** (), **mappedSection** (), and
        **clearMapping** ().
        """
        ...

    @typing.overload
    def addMapping(
        self, widget: QWidget, section: int, propertyName: QtCore.QByteArray
    ) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#addMapping-1

        **void QDataWidgetMapper::addMapping(QWidget * widget , int section ,
        const QByteArray & propertyName )**

        Essentially the same as addMapping(), but adds the possibility to
        specify the property to use specifying **propertyName**.

        **See also** **addMapping** ().
        """
        ...

    def submitPolicy(self) -> "QDataWidgetMapper.SubmitPolicy":
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#submitPolicy-prop

        **submitPolicy : SubmitPolicy**

        This property holds the current submit policy

        Changing the current submit policy will revert all widgets to the
        current data from the model.

        **Access functions:**

        QDataWidgetMapper::SubmitPolicy **submitPolicy** () const
        void
        **setSubmitPolicy** (QDataWidgetMapper::SubmitPolicy **policy** )

        **Member Function Documentation**
        """
        ...

    def setSubmitPolicy(self, policy: "QDataWidgetMapper.SubmitPolicy") -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#submitPolicy-prop

        **submitPolicy : SubmitPolicy**

        This property holds the current submit policy

        Changing the current submit policy will revert all widgets to the
        current data from the model.

        **Access functions:**

        QDataWidgetMapper::SubmitPolicy **submitPolicy** () const
        void
        **setSubmitPolicy** (QDataWidgetMapper::SubmitPolicy **policy** )

        **Member Function Documentation**
        """
        ...

    def orientation(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the model

        If the orientation is **Qt::Horizontal**  (the default), a widget is
        mapped to a column of a data model. The widget will be populated with
        the model's data from its mapped column and the row that
        **currentIndex** () points at.

        Use **Qt::Horizontal**  for tabular data that looks like this:

        1Qt NorwayOslo
        2Qt AustraliaBrisbane
        3Qt USASilicon Valley
        4Qt
        ChinaBeijing
        5Qt GermanyBerlin

        If the orientation is set to **Qt::Vertical** , a widget is mapped to a
        row. Calling **setCurrentIndex** () will change the current column. The
        widget will be populates with the model's data from its mapped row and
        the column that **currentIndex** () points at.

        Use **Qt::Vertical**  for tabular data that looks like this:

        12345
        Qt NorwayQt AustraliaQt USAQt ChinaQt Germany
        OsloBrisbaneSilicon ValleyBeijingBerlin

        Changing the orientation clears all existing mappings.

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation **aOrientation** )
        """
        ...

    def setOrientation(self, aOrientation: QtCore.Qt.Orientation) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#orientation-prop

        **orientation : Qt::Orientation**

        This property holds the orientation of the model

        If the orientation is **Qt::Horizontal**  (the default), a widget is
        mapped to a column of a data model. The widget will be populated with
        the model's data from its mapped column and the row that
        **currentIndex** () points at.

        Use **Qt::Horizontal**  for tabular data that looks like this:

        1Qt NorwayOslo
        2Qt AustraliaBrisbane
        3Qt USASilicon Valley
        4Qt
        ChinaBeijing
        5Qt GermanyBerlin

        If the orientation is set to **Qt::Vertical** , a widget is mapped to a
        row. Calling **setCurrentIndex** () will change the current column. The
        widget will be populates with the model's data from its mapped row and
        the column that **currentIndex** () points at.

        Use **Qt::Vertical**  for tabular data that looks like this:

        12345
        Qt NorwayQt AustraliaQt USAQt ChinaQt Germany
        OsloBrisbaneSilicon ValleyBeijingBerlin

        Changing the orientation clears all existing mappings.

        **Access functions:**

        Qt::Orientation **orientation** () const
        void **setOrientation**
        (Qt::Orientation **aOrientation** )
        """
        ...

    def rootIndex(self) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#rootIndex

        **QModelIndex QDataWidgetMapper::rootIndex() const**

        Returns the current root index.

        **See also** **setRootIndex** ().
        """
        ...

    def setRootIndex(self, index: QtCore.QModelIndex) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#setRootIndex

        **void QDataWidgetMapper::setRootIndex(const QModelIndex & index )**

        Sets the root item to **index**. This can be used to display a branch of
        a tree. Pass an invalid model index to display the top-most branch.

        **See also** **rootIndex** ().
        """
        ...

    def itemDelegate(self) -> QAbstractItemDelegate:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#itemDelegate

        **QAbstractItemDelegate *QDataWidgetMapper::itemDelegate() const**

        Returns the current item delegate.

        **See also** **setItemDelegate** ().
        """
        ...

    def setItemDelegate(self, delegate: QAbstractItemDelegate) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#setItemDelegate

        **void QDataWidgetMapper::setItemDelegate(QAbstractItemDelegate *
        delegate )**

        Sets the item delegate to **delegate**. The delegate will be used to
        write data from the model into the widget and from the widget to the
        model, using **QAbstractItemDelegate::setEditorData** () and
        **QAbstractItemDelegate::setModelData** ().

        Any existing delegate will be removed, but not deleted.
        **QDataWidgetMapper**  does not take ownership of **delegate**.

        The delegate also decides when to apply data and when to change the
        editor, using **QAbstractItemDelegate::commitData** () and
        **QAbstractItemDelegate::closeEditor** ().

        **Warning:** You should not share the same instance of a delegate
        between widget mappers or views. Doing so can cause incorrect or
        unintuitive editing behavior since each view connected to a given
        delegate may receive the **closeEditor** () signal, and attempt to
        access, modify or close an editor that has already been closed.

        **See also** **itemDelegate** ().
        """
        ...

    def model(self) -> QtCore.QAbstractItemModel:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#model

        **QAbstractItemModel *QDataWidgetMapper::model() const**

        Returns the current model.

        **See also** **setModel** ().
        """
        ...

    def setModel(self, model: QtCore.QAbstractItemModel) -> None:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#setModel

        **void QDataWidgetMapper::setModel(QAbstractItemModel * model )**

        Sets the current model to **model**. If another model was set, all
        mappings to that old model are cleared.

        **See also** **model** ().
        """
        ...

    @property
    def currentIndexChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qdatawidgetmapper.html#currentIndexChanged

        **[signal] void QDataWidgetMapper::currentIndexChanged(int index )**

        This signal is emitted after the current index has changed and all
        widgets were populated with new data. **index** is the new current
        index.

        **Note:** Notifier signal for property **currentIndex** .

        **See also** **currentIndex** () and **setCurrentIndex** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtOpenGL import *


class QOpenGLFunctions_2_1(QAbstractOpenGLFunctions):
    """
    https://doc.qt.io/qt-6/qopenglfunctions-2-1.html

    **Detailed Description**

    This class is a wrapper for functions from OpenGL 2.1 specification. See
    reference pages on **opengl.org**  for function documentation.

    **See also** **QAbstractOpenGLFunctions** .
    """

    def __init__(self) -> None:
        ...

    def glVertexAttrib1d(self, index: int, x: float) -> None:
        ...

    def glVertexAttrib1dv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib1f(self, index: int, x: float) -> None:
        ...

    def glVertexAttrib1fv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib1s(self, index: int, x: int) -> None:
        ...

    def glVertexAttrib1sv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib2d(self, index: int, x: float, y: float) -> None:
        ...

    def glVertexAttrib2dv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib2f(self, index: int, x: float, y: float) -> None:
        ...

    def glVertexAttrib2fv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib2s(self, index: int, x: int, y: int) -> None:
        ...

    def glVertexAttrib2sv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib3d(self, index: int, x: float, y: float, z: float) -> None:
        ...

    def glVertexAttrib3dv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib3f(self, index: int, x: float, y: float, z: float) -> None:
        ...

    def glVertexAttrib3fv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib3s(self, index: int, x: int, y: int, z: int) -> None:
        ...

    def glVertexAttrib3sv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4Nbv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4Niv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4Nsv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4Nub(self, index: int, x: int, y: int, z: int, w: int) -> None:
        ...

    def glVertexAttrib4Nubv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4Nuiv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4Nusv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4bv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4d(
        self, index: int, x: float, y: float, z: float, w: float
    ) -> None:
        ...

    def glVertexAttrib4dv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4f(
        self, index: int, x: float, y: float, z: float, w: float
    ) -> None:
        ...

    def glVertexAttrib4fv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4iv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4s(self, index: int, x: int, y: int, z: int, w: int) -> None:
        ...

    def glVertexAttrib4sv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4ubv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4uiv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertexAttrib4usv(self, index: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glFogCoordf(self, coord: float) -> None:
        ...

    def glFogCoordfv(self, coord: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glFogCoordd(self, coord: float) -> None:
        ...

    def glFogCoorddv(self, coord: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glFogCoordPointer(
        self, type: int, stride: int, pointer: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glSecondaryColor3b(self, red: int, green: int, blue: int) -> None:
        ...

    def glSecondaryColor3bv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3d(self, red: float, green: float, blue: float) -> None:
        ...

    def glSecondaryColor3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3f(self, red: float, green: float, blue: float) -> None:
        ...

    def glSecondaryColor3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3i(self, red: int, green: int, blue: int) -> None:
        ...

    def glSecondaryColor3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3s(self, red: int, green: int, blue: int) -> None:
        ...

    def glSecondaryColor3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3ub(self, red: int, green: int, blue: int) -> None:
        ...

    def glSecondaryColor3ubv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3ui(self, red: int, green: int, blue: int) -> None:
        ...

    def glSecondaryColor3uiv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColor3us(self, red: int, green: int, blue: int) -> None:
        ...

    def glSecondaryColor3usv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glSecondaryColorPointer(
        self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glWindowPos2d(self, x: float, y: float) -> None:
        ...

    def glWindowPos2dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos2f(self, x: float, y: float) -> None:
        ...

    def glWindowPos2fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos2i(self, x: int, y: int) -> None:
        ...

    def glWindowPos2iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos2s(self, x: int, y: int) -> None:
        ...

    def glWindowPos2sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos3d(self, x: float, y: float, z: float) -> None:
        ...

    def glWindowPos3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos3f(self, x: float, y: float, z: float) -> None:
        ...

    def glWindowPos3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos3i(self, x: int, y: int, z: int) -> None:
        ...

    def glWindowPos3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glWindowPos3s(self, x: int, y: int, z: int) -> None:
        ...

    def glWindowPos3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glClientActiveTexture(self, texture: int) -> None:
        ...

    def glMultiTexCoord1d(self, target: int, s: float) -> None:
        ...

    def glMultiTexCoord1dv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord1f(self, target: int, s: float) -> None:
        ...

    def glMultiTexCoord1fv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord1i(self, target: int, s: int) -> None:
        ...

    def glMultiTexCoord1iv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord1s(self, target: int, s: int) -> None:
        ...

    def glMultiTexCoord1sv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord2d(self, target: int, s: float, t: float) -> None:
        ...

    def glMultiTexCoord2dv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord2f(self, target: int, s: float, t: float) -> None:
        ...

    def glMultiTexCoord2fv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord2i(self, target: int, s: int, t: int) -> None:
        ...

    def glMultiTexCoord2iv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord2s(self, target: int, s: int, t: int) -> None:
        ...

    def glMultiTexCoord2sv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord3d(self, target: int, s: float, t: float, r: float) -> None:
        ...

    def glMultiTexCoord3dv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord3f(self, target: int, s: float, t: float, r: float) -> None:
        ...

    def glMultiTexCoord3fv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord3i(self, target: int, s: int, t: int, r: int) -> None:
        ...

    def glMultiTexCoord3iv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord3s(self, target: int, s: int, t: int, r: int) -> None:
        ...

    def glMultiTexCoord3sv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord4d(
        self, target: int, s: float, t: float, r: float, q: float
    ) -> None:
        ...

    def glMultiTexCoord4dv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord4f(
        self, target: int, s: float, t: float, r: float, q: float
    ) -> None:
        ...

    def glMultiTexCoord4fv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord4i(self, target: int, s: int, t: int, r: int, q: int) -> None:
        ...

    def glMultiTexCoord4iv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultiTexCoord4s(self, target: int, s: int, t: int, r: int, q: int) -> None:
        ...

    def glMultiTexCoord4sv(self, target: int, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLoadTransposeMatrixf(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLoadTransposeMatrixd(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultTransposeMatrixf(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultTransposeMatrixd(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColorTable(
        self,
        target: int,
        internalformat: int,
        width: int,
        format: int,
        type: int,
        table: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glColorTableParameterfv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glColorTableParameteriv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glCopyColorTable(
        self, target: int, internalformat: int, x: int, y: int, width: int
    ) -> None:
        ...

    def glGetColorTableParameterfv(
        self, target: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetColorTableParameteriv(
        self, target: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glColorSubTable(
        self,
        target: int,
        start: int,
        count: int,
        format: int,
        type: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCopyColorSubTable(
        self, target: int, start: int, x: int, y: int, width: int
    ) -> None:
        ...

    def glConvolutionFilter1D(
        self,
        target: int,
        internalformat: int,
        width: int,
        format: int,
        type: int,
        image: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glConvolutionFilter2D(
        self,
        target: int,
        internalformat: int,
        width: int,
        height: int,
        format: int,
        type: int,
        image: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glConvolutionParameterf(self, target: int, pname: int, params: float) -> None:
        ...

    def glConvolutionParameterfv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glConvolutionParameteri(self, target: int, pname: int, params: int) -> None:
        ...

    def glConvolutionParameteriv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glCopyConvolutionFilter1D(
        self, target: int, internalformat: int, x: int, y: int, width: int
    ) -> None:
        ...

    def glCopyConvolutionFilter2D(
        self, target: int, internalformat: int, x: int, y: int, width: int, height: int
    ) -> None:
        ...

    def glGetConvolutionParameterfv(
        self, target: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetConvolutionParameteriv(
        self, target: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glHistogram(
        self, target: int, width: int, internalformat: int, sink: int
    ) -> None:
        ...

    def glMinmax(self, target: int, internalformat: int, sink: int) -> None:
        ...

    def glResetHistogram(self, target: int) -> None:
        ...

    def glResetMinmax(self, target: int) -> None:
        ...

    def glArrayElement(self, i: int) -> None:
        ...

    def glColorPointer(
        self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY
    ) -> None:
        ...

    def glDisableClientState(self, array: int) -> None:
        ...

    def glEdgeFlagPointer(self, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY) -> None:
        ...

    def glEnableClientState(self, array: int) -> None:
        ...

    def glIndexPointer(
        self, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY
    ) -> None:
        ...

    def glNormalPointer(
        self, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY
    ) -> None:
        ...

    def glTexCoordPointer(
        self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY
    ) -> None:
        ...

    def glVertexPointer(
        self, size: int, type: int, stride: int, pointer: PYQT_OPENGL_BOUND_ARRAY
    ) -> None:
        ...

    def glPopClientAttrib(self) -> None:
        ...

    def glPushClientAttrib(self, mask: int) -> None:
        ...

    def glNewList(self, list: int, mode: int) -> None:
        ...

    def glEndList(self) -> None:
        ...

    def glCallList(self, list: int) -> None:
        ...

    def glDeleteLists(self, list: int, range: int) -> None:
        ...

    def glGenLists(self, range: int) -> int:
        ...

    def glListBase(self, base: int) -> None:
        ...

    def glBegin(self, mode: int) -> None:
        ...

    def glBitmap(
        self,
        width: int,
        height: int,
        xorig: float,
        yorig: float,
        xmove: float,
        ymove: float,
        bitmap: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glColor3b(self, red: int, green: int, blue: int) -> None:
        ...

    def glColor3bv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3d(self, red: float, green: float, blue: float) -> None:
        ...

    def glColor3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3f(self, red: float, green: float, blue: float) -> None:
        ...

    def glColor3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3i(self, red: int, green: int, blue: int) -> None:
        ...

    def glColor3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3s(self, red: int, green: int, blue: int) -> None:
        ...

    def glColor3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3ub(self, red: int, green: int, blue: int) -> None:
        ...

    def glColor3ubv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3ui(self, red: int, green: int, blue: int) -> None:
        ...

    def glColor3uiv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor3us(self, red: int, green: int, blue: int) -> None:
        ...

    def glColor3usv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4b(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glColor4bv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4d(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glColor4dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4f(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glColor4fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4i(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glColor4iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4s(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glColor4sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4ub(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glColor4ubv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4ui(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glColor4uiv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColor4us(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glColor4usv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glEdgeFlag(self, flag: int) -> None:
        ...

    def glEdgeFlagv(self, flag: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glEnd(self) -> None:
        ...

    def glIndexd(self, c: float) -> None:
        ...

    def glIndexdv(self, c: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glIndexf(self, c: float) -> None:
        ...

    def glIndexfv(self, c: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glIndexi(self, c: int) -> None:
        ...

    def glIndexiv(self, c: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glIndexs(self, c: int) -> None:
        ...

    def glIndexsv(self, c: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glNormal3b(self, nx: int, ny: int, nz: int) -> None:
        ...

    def glNormal3bv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glNormal3d(self, nx: float, ny: float, nz: float) -> None:
        ...

    def glNormal3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glNormal3f(self, nx: float, ny: float, nz: float) -> None:
        ...

    def glNormal3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glNormal3i(self, nx: int, ny: int, nz: int) -> None:
        ...

    def glNormal3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glNormal3s(self, nx: int, ny: int, nz: int) -> None:
        ...

    def glNormal3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos2d(self, x: float, y: float) -> None:
        ...

    def glRasterPos2dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos2f(self, x: float, y: float) -> None:
        ...

    def glRasterPos2fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos2i(self, x: int, y: int) -> None:
        ...

    def glRasterPos2iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos2s(self, x: int, y: int) -> None:
        ...

    def glRasterPos2sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos3d(self, x: float, y: float, z: float) -> None:
        ...

    def glRasterPos3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos3f(self, x: float, y: float, z: float) -> None:
        ...

    def glRasterPos3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos3i(self, x: int, y: int, z: int) -> None:
        ...

    def glRasterPos3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos3s(self, x: int, y: int, z: int) -> None:
        ...

    def glRasterPos3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos4d(self, x: float, y: float, z: float, w: float) -> None:
        ...

    def glRasterPos4dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos4f(self, x: float, y: float, z: float, w: float) -> None:
        ...

    def glRasterPos4fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos4i(self, x: int, y: int, z: int, w: int) -> None:
        ...

    def glRasterPos4iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRasterPos4s(self, x: int, y: int, z: int, w: int) -> None:
        ...

    def glRasterPos4sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRectd(self, x1: float, y1: float, x2: float, y2: float) -> None:
        ...

    def glRectf(self, x1: float, y1: float, x2: float, y2: float) -> None:
        ...

    def glRecti(self, x1: int, y1: int, x2: int, y2: int) -> None:
        ...

    def glRects(self, x1: int, y1: int, x2: int, y2: int) -> None:
        ...

    def glTexCoord1d(self, s: float) -> None:
        ...

    def glTexCoord1dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord1f(self, s: float) -> None:
        ...

    def glTexCoord1fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord1i(self, s: int) -> None:
        ...

    def glTexCoord1iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord1s(self, s: int) -> None:
        ...

    def glTexCoord1sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord2d(self, s: float, t: float) -> None:
        ...

    def glTexCoord2dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord2f(self, s: float, t: float) -> None:
        ...

    def glTexCoord2fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord2i(self, s: int, t: int) -> None:
        ...

    def glTexCoord2iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord2s(self, s: int, t: int) -> None:
        ...

    def glTexCoord2sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord3d(self, s: float, t: float, r: float) -> None:
        ...

    def glTexCoord3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord3f(self, s: float, t: float, r: float) -> None:
        ...

    def glTexCoord3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord3i(self, s: int, t: int, r: int) -> None:
        ...

    def glTexCoord3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord3s(self, s: int, t: int, r: int) -> None:
        ...

    def glTexCoord3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord4d(self, s: float, t: float, r: float, q: float) -> None:
        ...

    def glTexCoord4dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord4f(self, s: float, t: float, r: float, q: float) -> None:
        ...

    def glTexCoord4fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord4i(self, s: int, t: int, r: int, q: int) -> None:
        ...

    def glTexCoord4iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexCoord4s(self, s: int, t: int, r: int, q: int) -> None:
        ...

    def glTexCoord4sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex2d(self, x: float, y: float) -> None:
        ...

    def glVertex2dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex2f(self, x: float, y: float) -> None:
        ...

    def glVertex2fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex2i(self, x: int, y: int) -> None:
        ...

    def glVertex2iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex2s(self, x: int, y: int) -> None:
        ...

    def glVertex2sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex3d(self, x: float, y: float, z: float) -> None:
        ...

    def glVertex3dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex3f(self, x: float, y: float, z: float) -> None:
        ...

    def glVertex3fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex3i(self, x: int, y: int, z: int) -> None:
        ...

    def glVertex3iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex3s(self, x: int, y: int, z: int) -> None:
        ...

    def glVertex3sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex4d(self, x: float, y: float, z: float, w: float) -> None:
        ...

    def glVertex4dv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex4f(self, x: float, y: float, z: float, w: float) -> None:
        ...

    def glVertex4fv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex4i(self, x: int, y: int, z: int, w: int) -> None:
        ...

    def glVertex4iv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glVertex4s(self, x: int, y: int, z: int, w: int) -> None:
        ...

    def glVertex4sv(self, v: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glClipPlane(self, plane: int, equation: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glColorMaterial(self, face: int, mode: int) -> None:
        ...

    def glFogf(self, pname: int, param: float) -> None:
        ...

    def glFogfv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glFogi(self, pname: int, param: int) -> None:
        ...

    def glFogiv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLightf(self, light: int, pname: int, param: float) -> None:
        ...

    def glLightfv(self, light: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLighti(self, light: int, pname: int, param: int) -> None:
        ...

    def glLightiv(self, light: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLightModelf(self, pname: int, param: float) -> None:
        ...

    def glLightModelfv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLightModeli(self, pname: int, param: int) -> None:
        ...

    def glLightModeliv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLineStipple(self, factor: int, pattern: int) -> None:
        ...

    def glMaterialf(self, face: int, pname: int, param: float) -> None:
        ...

    def glMaterialfv(self, face: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMateriali(self, face: int, pname: int, param: int) -> None:
        ...

    def glMaterialiv(self, face: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glPolygonStipple(self, mask: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glShadeModel(self, mode: int) -> None:
        ...

    def glTexEnvf(self, target: int, pname: int, param: float) -> None:
        ...

    def glTexEnvfv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexEnvi(self, target: int, pname: int, param: int) -> None:
        ...

    def glTexEnviv(self, target: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexGend(self, coord: int, pname: int, param: float) -> None:
        ...

    def glTexGendv(self, coord: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexGenf(self, coord: int, pname: int, param: float) -> None:
        ...

    def glTexGenfv(self, coord: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glTexGeni(self, coord: int, pname: int, param: int) -> None:
        ...

    def glTexGeniv(self, coord: int, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glRenderMode(self, mode: int) -> int:
        ...

    def glInitNames(self) -> None:
        ...

    def glLoadName(self, name: int) -> None:
        ...

    def glPassThrough(self, token: float) -> None:
        ...

    def glPopName(self) -> None:
        ...

    def glPushName(self, name: int) -> None:
        ...

    def glClearAccum(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glClearIndex(self, c: float) -> None:
        ...

    def glIndexMask(self, mask: int) -> None:
        ...

    def glAccum(self, op: int, value: float) -> None:
        ...

    def glPopAttrib(self) -> None:
        ...

    def glPushAttrib(self, mask: int) -> None:
        ...

    def glMap1d(
        self,
        target: int,
        u1: float,
        u2: float,
        stride: int,
        order: int,
        points: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glMap1f(
        self,
        target: int,
        u1: float,
        u2: float,
        stride: int,
        order: int,
        points: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glMap2d(
        self,
        target: int,
        u1: float,
        u2: float,
        ustride: int,
        uorder: int,
        v1: float,
        v2: float,
        vstride: int,
        vorder: int,
        points: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glMap2f(
        self,
        target: int,
        u1: float,
        u2: float,
        ustride: int,
        uorder: int,
        v1: float,
        v2: float,
        vstride: int,
        vorder: int,
        points: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glMapGrid1d(self, un: int, u1: float, u2: float) -> None:
        ...

    def glMapGrid1f(self, un: int, u1: float, u2: float) -> None:
        ...

    def glMapGrid2d(
        self, un: int, u1: float, u2: float, vn: int, v1: float, v2: float
    ) -> None:
        ...

    def glMapGrid2f(
        self, un: int, u1: float, u2: float, vn: int, v1: float, v2: float
    ) -> None:
        ...

    def glEvalCoord1d(self, u: float) -> None:
        ...

    def glEvalCoord1dv(self, u: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glEvalCoord1f(self, u: float) -> None:
        ...

    def glEvalCoord1fv(self, u: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glEvalCoord2d(self, u: float, v: float) -> None:
        ...

    def glEvalCoord2dv(self, u: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glEvalCoord2f(self, u: float, v: float) -> None:
        ...

    def glEvalCoord2fv(self, u: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glEvalMesh1(self, mode: int, i1: int, i2: int) -> None:
        ...

    def glEvalPoint1(self, i: int) -> None:
        ...

    def glEvalMesh2(self, mode: int, i1: int, i2: int, j1: int, j2: int) -> None:
        ...

    def glEvalPoint2(self, i: int, j: int) -> None:
        ...

    def glAlphaFunc(self, func: int, ref: float) -> None:
        ...

    def glPixelZoom(self, xfactor: float, yfactor: float) -> None:
        ...

    def glPixelTransferf(self, pname: int, param: float) -> None:
        ...

    def glPixelTransferi(self, pname: int, param: int) -> None:
        ...

    def glPixelMapfv(self, map: int, mapsize: int, values: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glPixelMapuiv(self, map: int, mapsize: int, values: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glPixelMapusv(self, map: int, mapsize: int, values: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glCopyPixels(self, x: int, y: int, width: int, height: int, type: int) -> None:
        ...

    def glDrawPixels(
        self, width: int, height: int, format: int, type: int, pixels: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glGetClipPlane(self, plane: int) -> typing.Tuple[float, float, float, float]:
        ...

    def glGetLightfv(
        self, light: int, pname: int
    ) -> typing.Union[
        float,
        typing.Tuple[float, float, float],
        typing.Tuple[float, float, float, float],
    ]:
        ...

    def glGetLightiv(
        self, light: int, pname: int
    ) -> typing.Union[
        int, typing.Tuple[int, int, int], typing.Tuple[int, int, int, int]
    ]:
        ...

    def glGetMaterialfv(
        self, face: int, pname: int
    ) -> typing.Union[
        float,
        typing.Tuple[float, float, float],
        typing.Tuple[float, float, float, float],
    ]:
        ...

    def glGetMaterialiv(
        self, face: int, pname: int
    ) -> typing.Union[
        int, typing.Tuple[int, int, int], typing.Tuple[int, int, int, int]
    ]:
        ...

    def glGetTexEnvfv(
        self, target: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetTexEnviv(
        self, target: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glGetTexGendv(
        self, coord: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetTexGenfv(
        self, coord: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetTexGeniv(
        self, coord: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glIsList(self, list: int) -> int:
        ...

    def glFrustum(
        self,
        left: float,
        right: float,
        bottom: float,
        top: float,
        zNear: float,
        zFar: float,
    ) -> None:
        ...

    def glLoadIdentity(self) -> None:
        ...

    def glLoadMatrixf(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glLoadMatrixd(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMatrixMode(self, mode: int) -> None:
        ...

    def glMultMatrixf(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glMultMatrixd(self, m: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glOrtho(
        self,
        left: float,
        right: float,
        bottom: float,
        top: float,
        zNear: float,
        zFar: float,
    ) -> None:
        ...

    def glPopMatrix(self) -> None:
        ...

    def glPushMatrix(self) -> None:
        ...

    def glRotated(self, angle: float, x: float, y: float, z: float) -> None:
        ...

    def glRotatef(self, angle: float, x: float, y: float, z: float) -> None:
        ...

    def glScaled(self, x: float, y: float, z: float) -> None:
        ...

    def glScalef(self, x: float, y: float, z: float) -> None:
        ...

    def glTranslated(self, x: float, y: float, z: float) -> None:
        ...

    def glTranslatef(self, x: float, y: float, z: float) -> None:
        ...

    def glBlendEquationSeparate(self, modeRGB: int, modeAlpha: int) -> None:
        ...

    def glDrawBuffers(self, n: int, bufs: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glStencilOpSeparate(
        self, face: int, sfail: int, dpfail: int, dppass: int
    ) -> None:
        ...

    def glStencilFuncSeparate(self, face: int, func: int, ref: int, mask: int) -> None:
        ...

    def glStencilMaskSeparate(self, face: int, mask: int) -> None:
        ...

    def glAttachShader(self, program: int, shader: int) -> None:
        ...

    def glBindAttribLocation(self, program: int, index: int, name: str) -> None:
        ...

    def glCompileShader(self, shader: int) -> None:
        ...

    def glCreateProgram(self) -> int:
        ...

    def glCreateShader(self, type: int) -> int:
        ...

    def glDeleteProgram(self, program: int) -> None:
        ...

    def glDeleteShader(self, shader: int) -> None:
        ...

    def glDetachShader(self, program: int, shader: int) -> None:
        ...

    def glDisableVertexAttribArray(self, index: int) -> None:
        ...

    def glEnableVertexAttribArray(self, index: int) -> None:
        ...

    def glGetActiveAttrib(
        self, program: int, index: int
    ) -> typing.Tuple[str, int, int]:
        ...

    def glGetActiveUniform(
        self, program: int, index: int
    ) -> typing.Tuple[str, int, int]:
        ...

    def glGetAttachedShaders(self, program: int) -> typing.Tuple[int, ...]:
        ...

    def glGetAttribLocation(self, program: int, name: str) -> int:
        ...

    def glGetProgramiv(
        self, program: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int]]:
        ...

    def glGetProgramInfoLog(self, program: int) -> bytes:
        ...

    def glGetShaderiv(self, shader: int, pname: int) -> int:
        ...

    def glGetShaderInfoLog(self, shader: int) -> bytes:
        ...

    def glGetShaderSource(self, shader: int) -> bytes:
        ...

    def glGetUniformLocation(self, program: int, name: str) -> int:
        ...

    def glGetVertexAttribdv(
        self, index: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetVertexAttribfv(
        self, index: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetVertexAttribiv(
        self, index: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glIsProgram(self, program: int) -> int:
        ...

    def glIsShader(self, shader: int) -> int:
        ...

    def glLinkProgram(self, program: int) -> None:
        ...

    def glUseProgram(self, program: int) -> None:
        ...

    def glUniform1f(self, location: int, v0: float) -> None:
        ...

    def glUniform2f(self, location: int, v0: float, v1: float) -> None:
        ...

    def glUniform3f(self, location: int, v0: float, v1: float, v2: float) -> None:
        ...

    def glUniform4f(
        self, location: int, v0: float, v1: float, v2: float, v3: float
    ) -> None:
        ...

    def glUniform1i(self, location: int, v0: int) -> None:
        ...

    def glUniform2i(self, location: int, v0: int, v1: int) -> None:
        ...

    def glUniform3i(self, location: int, v0: int, v1: int, v2: int) -> None:
        ...

    def glUniform4i(self, location: int, v0: int, v1: int, v2: int, v3: int) -> None:
        ...

    def glUniform1fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform2fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform3fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform4fv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform1iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform2iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform3iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniform4iv(self, location: int, count: int, value: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glUniformMatrix2fv(
        self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glUniformMatrix3fv(
        self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glUniformMatrix4fv(
        self, location: int, count: int, transpose: int, value: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glValidateProgram(self, program: int) -> None:
        ...

    def glVertexAttribPointer(
        self,
        index: int,
        size: int,
        type: int,
        normalized: int,
        stride: int,
        pointer: PYQT_OPENGL_BOUND_ARRAY,
    ) -> None:
        ...

    def glGenQueries(self, n: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glDeleteQueries(self, n: int, ids: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glIsQuery(self, id: int) -> int:
        ...

    def glBeginQuery(self, target: int, id: int) -> None:
        ...

    def glEndQuery(self, target: int) -> None:
        ...

    def glGetQueryiv(self, target: int, pname: int) -> int:
        ...

    def glBindBuffer(self, target: int, buffer: int) -> None:
        ...

    def glDeleteBuffers(self, n: int, buffers: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glGenBuffers(self, n: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glIsBuffer(self, buffer: int) -> int:
        ...

    def glBufferData(
        self, target: int, size: int, data: PYQT_OPENGL_ARRAY, usage: int
    ) -> None:
        ...

    def glBufferSubData(
        self, target: int, offset: int, size: int, data: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glUnmapBuffer(self, target: int) -> int:
        ...

    def glGetBufferParameteriv(self, target: int, pname: int) -> int:
        ...

    def glBlendFuncSeparate(
        self, sfactorRGB: int, dfactorRGB: int, sfactorAlpha: int, dfactorAlpha: int
    ) -> None:
        ...

    def glPointParameterf(self, pname: int, param: float) -> None:
        ...

    def glPointParameterfv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glPointParameteri(self, pname: int, param: int) -> None:
        ...

    def glPointParameteriv(self, pname: int, params: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glActiveTexture(self, texture: int) -> None:
        ...

    def glSampleCoverage(self, value: float, invert: int) -> None:
        ...

    def glCompressedTexImage3D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        depth: int,
        border: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexImage2D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        border: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexImage1D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        border: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexSubImage3D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        zoffset: int,
        width: int,
        height: int,
        depth: int,
        format: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexSubImage2D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        width: int,
        height: int,
        format: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCompressedTexSubImage1D(
        self,
        target: int,
        level: int,
        xoffset: int,
        width: int,
        format: int,
        imageSize: int,
        data: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glBlendColor(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glBlendEquation(self, mode: int) -> None:
        ...

    def glDrawRangeElements(
        self,
        mode: int,
        start: int,
        end: int,
        count: int,
        type: int,
        indices: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexImage3D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        depth: int,
        border: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexSubImage3D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        zoffset: int,
        width: int,
        height: int,
        depth: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glCopyTexSubImage3D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        zoffset: int,
        x: int,
        y: int,
        width: int,
        height: int,
    ) -> None:
        ...

    def glDrawArrays(self, mode: int, first: int, count: int) -> None:
        ...

    def glDrawElements(
        self, mode: int, count: int, type: int, indices: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glPolygonOffset(self, factor: float, units: float) -> None:
        ...

    def glCopyTexImage1D(
        self,
        target: int,
        level: int,
        internalformat: int,
        x: int,
        y: int,
        width: int,
        border: int,
    ) -> None:
        ...

    def glCopyTexImage2D(
        self,
        target: int,
        level: int,
        internalformat: int,
        x: int,
        y: int,
        width: int,
        height: int,
        border: int,
    ) -> None:
        ...

    def glCopyTexSubImage1D(
        self, target: int, level: int, xoffset: int, x: int, y: int, width: int
    ) -> None:
        ...

    def glCopyTexSubImage2D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        x: int,
        y: int,
        width: int,
        height: int,
    ) -> None:
        ...

    def glTexSubImage1D(
        self,
        target: int,
        level: int,
        xoffset: int,
        width: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexSubImage2D(
        self,
        target: int,
        level: int,
        xoffset: int,
        yoffset: int,
        width: int,
        height: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glBindTexture(self, target: int, texture: int) -> None:
        ...

    def glDeleteTextures(self, n: int, textures: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glGenTextures(self, n: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glIsTexture(self, texture: int) -> int:
        ...

    def glIndexub(self, c: int) -> None:
        ...

    def glIndexubv(self, c: PYQT_OPENGL_ARRAY) -> None:
        ...

    def glCullFace(self, mode: int) -> None:
        ...

    def glFrontFace(self, mode: int) -> None:
        ...

    def glHint(self, target: int, mode: int) -> None:
        ...

    def glLineWidth(self, width: float) -> None:
        ...

    def glPointSize(self, size: float) -> None:
        ...

    def glPolygonMode(self, face: int, mode: int) -> None:
        ...

    def glScissor(self, x: int, y: int, width: int, height: int) -> None:
        ...

    def glTexParameterf(self, target: int, pname: int, param: float) -> None:
        ...

    def glTexParameterfv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glTexParameteri(self, target: int, pname: int, param: int) -> None:
        ...

    def glTexParameteriv(
        self, target: int, pname: int, params: PYQT_OPENGL_ARRAY
    ) -> None:
        ...

    def glTexImage1D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        border: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glTexImage2D(
        self,
        target: int,
        level: int,
        internalformat: int,
        width: int,
        height: int,
        border: int,
        format: int,
        type: int,
        pixels: PYQT_OPENGL_ARRAY,
    ) -> None:
        ...

    def glDrawBuffer(self, mode: int) -> None:
        ...

    def glClear(self, mask: int) -> None:
        ...

    def glClearColor(self, red: float, green: float, blue: float, alpha: float) -> None:
        ...

    def glClearStencil(self, s: int) -> None:
        ...

    def glClearDepth(self, depth: float) -> None:
        ...

    def glStencilMask(self, mask: int) -> None:
        ...

    def glColorMask(self, red: int, green: int, blue: int, alpha: int) -> None:
        ...

    def glDepthMask(self, flag: int) -> None:
        ...

    def glDisable(self, cap: int) -> None:
        ...

    def glEnable(self, cap: int) -> None:
        ...

    def glFinish(self) -> None:
        ...

    def glFlush(self) -> None:
        ...

    def glBlendFunc(self, sfactor: int, dfactor: int) -> None:
        ...

    def glLogicOp(self, opcode: int) -> None:
        ...

    def glStencilFunc(self, func: int, ref: int, mask: int) -> None:
        ...

    def glStencilOp(self, fail: int, zfail: int, zpass: int) -> None:
        ...

    def glDepthFunc(self, func: int) -> None:
        ...

    def glPixelStoref(self, pname: int, param: float) -> None:
        ...

    def glPixelStorei(self, pname: int, param: int) -> None:
        ...

    def glReadBuffer(self, mode: int) -> None:
        ...

    def glReadPixels(
        self, x: int, y: int, width: int, height: int, format: int, type: int
    ) -> typing.Union[typing.Tuple[float, ...], typing.Tuple[int, ...]]:
        ...

    def glGetBooleanv(self, pname: int) -> typing.Union[bool, typing.Tuple[bool, ...]]:
        ...

    def glGetDoublev(self, pname: int) -> typing.Union[float, typing.Tuple[float, ...]]:
        ...

    def glGetError(self) -> int:
        ...

    def glGetFloatv(self, pname: int) -> typing.Union[float, typing.Tuple[float, ...]]:
        ...

    def glGetIntegerv(self, pname: int) -> typing.Union[int, typing.Tuple[int, ...]]:
        ...

    def glGetString(self, name: int) -> str:
        ...

    def glGetTexParameterfv(
        self, target: int, pname: int
    ) -> typing.Union[float, typing.Tuple[float, float, float, float]]:
        ...

    def glGetTexParameteriv(
        self, target: int, pname: int
    ) -> typing.Union[int, typing.Tuple[int, int, int, int]]:
        ...

    def glGetTexLevelParameterfv(self, target: int, level: int, pname: int) -> float:
        ...

    def glGetTexLevelParameteriv(self, target: int, level: int, pname: int) -> int:
        ...

    def glIsEnabled(self, cap: int) -> int:
        ...

    def glDepthRange(self, nearVal: float, farVal: float) -> None:
        ...

    def glViewport(self, x: int, y: int, width: int, height: int) -> None:
        ...

    def initializeOpenGLFunctions(self) -> bool:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsSceneEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qgraphicssceneevent.html

    **Detailed Description**

    When a **QGraphicsView**  receives Qt mouse, keyboard, and drag and drop
    events (**QMouseEvent** , **QKeyEvent** , QDragEvent, etc.), it translates
    them into instances of QGraphicsSceneEvent subclasses and forwards them to
    the **QGraphicsScene**  it displays. The scene then forwards the events to
    the relevant items.

    For example, when a **QGraphicsView**  receives a **QMouseEvent**  of type
    MousePress as a response to a user click, the view sends a
    **QGraphicsSceneMouseEvent**  of type GraphicsSceneMousePress to the
    underlying **QGraphicsScene**  through its **mousePressEvent** () function.
    The default **QGraphicsScene::mousePressEvent** () implementation determines
    which item was clicked and forwards the event to
    **QGraphicsItem::mousePressEvent** ().

    Subclasses such as **QGraphicsSceneMouseEvent**  and
    **QGraphicsSceneContextMenuEvent**  provide the coordinates from the
    original **QEvent**  in screen, scene, and item coordinates (see
    **screenPos** (), **scenePos** (), and **pos** ()). The item coordinates are
    set by the **QGraphicsScene**  before it forwards the event to the event to
    a **QGraphicsItem** . The mouse events also add the possibility to retrieve
    the coordinates from the last event received by the view (see
    **lastScreenPos** (), **lastScenePos** (), and **lastPos** ()).

    **See also** **QEvent** .
    """

    def timestamp(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicssceneevent.html#timestamp

        **[since 6.2] quint64 QGraphicsSceneEvent::timestamp() const**

        Returns the timestamp of the original event, or 0 if the original event
        does not report a time stamp.

        This function was introduced in Qt 6.2.
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qgraphicssceneevent.html#widget

        **QWidget *QGraphicsSceneEvent::widget() const**

        Returns the widget where the event originated, or `nullptr` if the event
        originates from another application.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtCore import *
import enum


class QCborStreamReader(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qcborstreamreader.html

    **Detailed Description**

    This class can be used to decode a stream of CBOR content directly from
    either a **QByteArray**  or a **QIODevice** . CBOR is the Concise Binary
    Object Representation, a very compact form of binary data encoding that is
    compatible with JSON. It was created by the IETF Constrained RESTful
    Environments (CoRE) WG, which has used it in many new RFCs. It is meant to
    be used alongside the **CoAP protocol** .

    QCborStreamReader provides a StAX-like API, similar to that of
    **QXmlStreamReader** . Using it requires a bit of knowledge of CBOR
    encoding. For a simpler API, see **QCborValue**  and especially the decoding
    function **QCborValue::fromCbor** ().

    Typically, one creates a QCborStreamReader by passing the source
    **QByteArray**  or **QIODevice**  as a parameter to the constructor, then
    pop elements off the stream if there were no errors in decoding. There are
    three kinds of CBOR types:

    KindTypesBehavior
    Fixed-widthIntegers, Tags, Simple types, Floating
    pointValue is pre-parsed by QCborStreamReader, so accessor functions are
    `const`. Must call **next** () to advance.
    StringsByte arrays, Text
    stringsLength (if known) is pre-parsed, but the string itself is not. The
    accessor functions are not const and may allocate memory. Once called, the
    accessor functions automatically advance to the next element.
    ContainersArrays, MapsLength (if known) is pre-parsed. To access the
    elements, you must call **enterContainer** (), read all elements, then call
    **leaveContainer** (). That function advances to the next element.

    So a processor function typically looks like this:

    void handleStream(**QCborStreamReader**  &reader)
           {
               switch
    (reader.type())
               case **QCborStreamReader** ::UnsignedInteger:
    case **QCborStreamReader** ::NegativeInteger:
               case
    **QCborStreamReader** ::SimpleType:
               case **QCborStreamReader**
    ::Float16:
               case **QCborStreamReader** ::Float:
               case
    **QCborStreamReader** ::Double:
                   handleFixedWidth(reader);
    reader.next();
                   break;
               case **QCborStreamReader**
    ::ByteArray:
               case **QCborStreamReader** ::String:
    handleString(reader);
                   break;
               case
    **QCborStreamReader** ::Array:
               case **QCborStreamReader** ::Map:
    reader.enterContainer();
                   while (reader.lastError() ==
    **QCborError** ::NoError)
                       handleStream(reader);
    if (reader.lastError() == **QCborError** ::NoError)
    reader.leaveContainer();
               }
           }

    **CBOR support**

    The following table lists the CBOR features that QCborStreamReader supports.

    FeatureSupport
    Unsigned numbersYes (full range)
    Negative numbersYes
    (full range)
    Byte stringsYes
    Text stringsYes
    Chunked stringsYes
    TagsYes (arbitrary)
    BooleansYes
    NullYes
    UndefinedYes
    Arbitrary
    simple valuesYes
    Half-precision float (16-bit)Yes
    Single-precision float
    (32-bit)Yes
    Double-precision float (64-bit)Yes
    Infinities and NaN
    floating pointYes
    Determinate-length arrays and mapsYes
    Indeterminate-
    length arrays and mapsYes
    Map key types other than strings and integersYes
    (arbitrary)

    **Dealing with invalid or incomplete CBOR streams**

    QCborStreamReader is capable of detecting corrupt input on its own. The
    library it uses has been extensively tested against invalid input of any
    kind and is quite able to report errors. If any is detected,
    QCborStreamReader will set **lastError** () to a value besides
    **QCborError::NoError** , indicating which situation was detected.

    Most errors detected by QCborStreamReader during normal item parsing are not
    recoverable. The code using QCborStreamReader may opt to handle the data
    that was properly decoded or it can opt to discard the entire data.

    The only recoverable error is **QCborError::EndOfFile** , which indicates
    that more data is required in order to complete the parsing. This situation
    is useful when data is being read from an asynchronous source, such as a
    pipe (**QProcess** ) or a socket (**QTcpSocket** , **QUdpSocket** ,
    **QNetworkReply** , etc.). When more data arrives, the surrounding code
    needs to call either **addData** (), if parsing from a **QByteArray** , or
    **reparse** (), if it is instead reading directly a the QIDOevice that now
    has more data available (see **setDevice** ()).

    **See also** **QCborStreamWriter** , **QCborValue** , and
    **QXmlStreamReader** .
    """

    class StringResultCode(enum.Enum):
        EndOfString: QCborStreamReader = ...
        Ok: QCborStreamReader = ...
        Error: QCborStreamReader = ...

    class Type(enum.Enum):
        UnsignedInteger: QCborStreamReader = ...
        NegativeInteger: QCborStreamReader = ...
        ByteString: QCborStreamReader = ...
        ByteArray: QCborStreamReader = ...
        TextString: QCborStreamReader = ...
        String: QCborStreamReader = ...
        Array: QCborStreamReader = ...
        Map: QCborStreamReader = ...
        Tag: QCborStreamReader = ...
        SimpleType: QCborStreamReader = ...
        HalfFloat: QCborStreamReader = ...
        Float16: QCborStreamReader = ...
        Float: QCborStreamReader = ...
        Double: QCborStreamReader = ...
        Invalid: QCborStreamReader = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#QCborStreamReader

        **QCborStreamReader::QCborStreamReader()**

        Creates a QCborStreamReader object with no source data. After
        construction, QCborStreamReader will report an error parsing.

        You can add more data by calling **addData** () or by setting a
        different source device using **setDevice** ().

        **See also** **addData** () and **isValid** ().
        """
        ...

    @typing.overload
    def __init__(self, data: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#QCborStreamReader-1

        **QCborStreamReader::QCborStreamReader(const char * data , qsizetype len
        )**

        This is an overloaded function.

        Creates a QCborStreamReader object with **len** bytes of data starting
        at **data**. The pointer must remain valid until QCborStreamReader is
        destroyed.
        """
        ...

    @typing.overload
    def __init__(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#QCborStreamReader-2

        **QCborStreamReader::QCborStreamReader(const quint8 * data , qsizetype
        len )**

        This is an overloaded function.

        Creates a QCborStreamReader object with **len** bytes of data starting
        at **data**. The pointer must remain valid until QCborStreamReader is
        destroyed.
        """
        ...

    def toInteger(self) -> int:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#toInteger

        **qint64 QCborStreamReader::toInteger() const**

        Returns the integer value of the current element, be it negative,
        positive or zero. If the value is larger than 263 \\- 1 or smaller than
        -263, the returned value will overflow and will have an incorrect sign.
        If handling those values is required, use **toUnsignedInteger** () or
        **toNegativeInteger** () instead.

        This function does not perform any type conversions, including from
        boolean or CBOR tag. Therefore, it may only be called if **isInteger**
        () is true; calling it in any other condition is an error.

        **See also** **isInteger** (), **toUnsignedInteger** (), and
        **toNegativeInteger** ().
        """
        ...

    def toDouble(self) -> float:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#toDouble

        **double QCborStreamReader::toDouble() const**

        Returns the 64-bit double-precision floating point value of the current
        element.

        This function does not perform any type conversions, including from
        other floating point types or from integer values. Therefore, it may
        only be called if **isDouble** () is true; calling it in any other
        condition is an error.

        **See also** **isDouble** (), **toFloat16** (), and **toFloat** ().
        """
        ...

    def toSimpleType(self) -> QCborSimpleType:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#toSimpleType

        **QCborSimpleType QCborStreamReader::toSimpleType() const**

        Returns value of the current simple type.

        This function does not perform any type conversions, including from
        integer. Therefore, it may only be called if **isSimpleType** () is
        true; calling it in any other condition is an error.

        **See also** **isSimpleType** (), **isTrue** (), **isFalse** (),
        **isBool** (), **isNull** (), and **isUndefined** ().
        """
        ...

    def toUnsignedInteger(self) -> int:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#toUnsignedInteger

        **quint64 QCborStreamReader::toUnsignedInteger() const**

        Returns the unsigned integer value of the current element.

        This function does not perform any type conversions, including from
        boolean or CBOR tag. Therefore, it may only be called if
        **isUnsignedInteger** () is true; calling it in any other condition is
        an error.

        This function may be used to obtain numbers beyond the range of the
        return type of **toInteger** ().

        **See also** **type** (), **toInteger** (), **isUnsignedInteger** (),
        and **isNegativeInteger** ().
        """
        ...

    def toBool(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#toBool

        **bool QCborStreamReader::toBool() const**

        Returns the boolean value of the current element.

        This function does not perform any type conversions, including from
        integer. Therefore, it may only be called if **isTrue** (), **isFalse**
        () or **isBool** () returned true; calling it in any other condition is
        an error.

        **See also** **isBool** (), **isTrue** (), **isFalse** (), and
        **toInteger** ().
        """
        ...

    def readByteArray(
        self,
    ) -> typing.Tuple[QByteArray, "QCborStreamReader.StringResultCode"]:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#readByteArray

        **StringResult<QByteArray> QCborStreamReader::readByteArray()**

        Decodes one byte array chunk from the CBOR string and returns it. This
        function is used for both regular and chunked contents, so the caller
        must always loop around calling this function, even if **isLengthKnown**
        () has is true. The typical use of this function is as follows:

        QBytearray decodeBytearray(**QCborStreamReader**  &reader)
               {
        QBytearray result;
                   auto r = reader.readBytearray();
        while (r.code == **QCborStreamReader** ::Ok) {
                       result +=
        r.data;
                       r = reader.readByteArray();
                   }
        if (r.code == **QCborStreamReader** ::Error) {
                       // handle
        error condition
                       result.clear();
                   }
        return result;
               }

        This function does not perform any type conversions, including from
        integers or from strings. Therefore, it may only be called if
        **isByteArray** () is true; calling it in any other condition is an
        error.

        **See also** **readString** (), **isByteArray** (), and
        **readStringChunk** ().
        """
        ...

    def readString(self) -> typing.Tuple[str, "QCborStreamReader.StringResultCode"]:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#readString

        **StringResult<QString> QCborStreamReader::readString()**

        Decodes one string chunk from the CBOR string and returns it. This
        function is used for both regular and chunked string contents, so the
        caller must always loop around calling this function, even if
        **isLengthKnown** () has is true. The typical use of this function is as
        follows:

        **QString**  decodeString(**QCborStreamReader**  &reader)
               {
        **QString**  result;
                   auto r = reader.readString();
        while (r.code == **QCborStreamReader** ::Ok) {
                       result +=
        r.data;
                       r = reader.readString();
                   }
        if (r.code == **QCborStreamReader** ::Error) {
                       // handle
        error condition
                       result.clear();
                   }
        return result;
               }

        This function does not perform any type conversions, including from
        integers or from byte arrays. Therefore, it may only be called if
        **isString** () returned true; calling it in any other condition is an
        error.

        **See also** **readByteArray** (), **isString** (), and
        **readStringChunk** ().
        """
        ...

    def leaveContainer(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#leaveContainer

        **bool QCborStreamReader::leaveContainer()**

        Leaves the array or map whose items were being processed and positions
        the decoder at the next item after the end of the container. Returns
        true if leaving the container succeeded, false otherwise (usually, a
        parsing error). Each call to **enterContainer** () must be paired with a
        call to leaveContainer().

        This function may only be called if **hasNext** () has returned false
        and **containerDepth** () is not zero. Calling it in any other condition
        is an error.

        **See also** **enterContainer** (), **parentContainerType** (), and
        **containerDepth** ().
        """
        ...

    def enterContainer(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#enterContainer

        **bool QCborStreamReader::enterContainer()**

        Enters the array or map that is the current item and prepares for
        iterating the elements contained in the container. Returns true if
        entering the container succeeded, false otherwise (usually, a parsing
        error). Each call to enterContainer() must be paired with a call to
        **leaveContainer** ().

        This function may only be called if the current item is an array or a
        map (that is, if **isArray** (), **isMap** () or **isContainer** () is
        true). Calling it in any other condition is an error.

        **See also** **leaveContainer** (), **isContainer** (), **isArray** (),
        and **isMap** ().
        """
        ...

    def isContainer(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isContainer

        **bool QCborStreamReader::isContainer() const**

        Returns true if the current element is a container (that is, an array or
        a map), false if it is anything else. If the current element is a
        container, the **isLengthKnown** () function may be used to find out if
        the container's size is explicit in the stream and, if so, **length** ()
        can be used to get that size.

        More importantly, for a container, the **enterContainer** () function is
        available to begin iterating through the elements contained therein.

        **See also** **type** (), **isArray** (), **isMap** (),
        **isLengthKnown** (), **length** (), **enterContainer** (),
        **leaveContainer** (), and **containerDepth** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def length(self) -> int:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#length

        **quint64 QCborStreamReader::length() const**

        Returns the length of the string or byte array, or the number of items
        in an array or the number, of item pairs in a map, if known. This
        function must not be called if the length is unknown (that is, if
        **isLengthKnown** () returned false). It is an error to do that and it
        will cause **QCborStreamReader**  to stop parsing the input stream.

        **See also** **isLengthKnown** (), **QCborStreamWriter::startArray** (),
        and **QCborStreamWriter::startMap** ().
        """
        ...

    def isLengthKnown(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isLengthKnown

        **bool QCborStreamReader::isLengthKnown() const**

        Returns true if the length of the current array, map, byte array or
        string is known (explicit in the CBOR stream), false otherwise. This
        function should only be called if the element is one of those.

        If the length is known, it may be obtained by calling **length** ().

        If the length of a map or an array is not known, it is implied by the
        number of elements present in the stream. **QCborStreamReader**  has no
        API to calculate the length in that condition.

        Strings and byte arrays may also have indeterminate length (that is,
        they may be transmitted in multiple chunks). Those cannot currently be
        created with **QCborStreamWriter** , but they could be with other
        encoders, so **QCborStreamReader**  supports them.

        **See also** **length** (), **QCborStreamWriter::startArray** (), and
        **QCborStreamWriter::startMap** ().
        """
        ...

    def isUndefined(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isUndefined

        **bool QCborStreamReader::isUndefined() const**

        Returns true if the current element is the `undefined` value, false if
        it is anything else. Undefined values may be encoded to indicate that
        some conversion failed or was not possible when creating the stream.
        **QCborStreamReader**  never performs any replacement and this function
        will only return true if the stream contains an explicit undefined
        value.

        **See also** **type** (), **isSimpleType** (), and **toSimpleType** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isNull

        **bool QCborStreamReader::isNull() const**

        Returns true if the current element is the `null` value, false if it is
        anything else. Null values may be used to indicate the absence of some
        optional data.

        **Note:** This function is not the opposite of **isValid** (). A Null
        value is a valid CBOR value.

        **See also** **type** (), **isSimpleType** (), and **toSimpleType** ().
        """
        ...

    def isBool(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isBool

        **bool QCborStreamReader::isBool() const**

        Returns true if the current element is a boolean value (`true` or
        `false`), false if it is anything else. If this function returns true,
        you may call **toBool** () to retrieve the value of the boolean. You may
        also call **toSimpleType** () and compare to either
        QCborSimpleValue::True or QCborSimpleValue::False.

        **See also** **type** (), **isFalse** (), **isTrue** (), **toBool** (),
        **isSimpleType** (), and **toSimpleType** ().
        """
        ...

    def isTrue(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isTrue

        **bool QCborStreamReader::isTrue() const**

        Returns true if the current element is the `true` value, false if it is
        anything else.

        **See also** **type** (), **isFalse** (), **isBool** (), **toBool** (),
        **isSimpleType** (), and **toSimpleType** ().
        """
        ...

    def isFalse(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isFalse

        **bool QCborStreamReader::isFalse() const**

        Returns true if the current element is the `false` value, false if it is
        anything else.

        **See also** **type** (), **isTrue** (), **isBool** (), **toBool** (),
        **isSimpleType** (), and **toSimpleType** ().
        """
        ...

    def isInvalid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isInvalid

        **bool QCborStreamReader::isInvalid() const**

        Returns true if the current element is invalid, false otherwise. The
        current element may be invalid if there was a decoding error or we've
        just parsed the last element in an array or map.

        **Note:** This function is not to be confused with **isNull** (). Null
        is a normal CBOR type that must be handled by the application.

        **See also** **type** () and **isValid** ().
        """
        ...

    def isDouble(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isDouble

        **bool QCborStreamReader::isDouble() const**

        Returns true if the type of the current element is an IEEE 754 double-
        precision floating point (that is, if **type** () returns
        **QCborStreamReader::Double** ). If this function returns true, you may
        call **toDouble** () to read that data.

        **See also** **type** (), **toDouble** (), **isFloat16** (), and
        **isFloat** ().
        """
        ...

    def isFloat(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isFloat

        **bool QCborStreamReader::isFloat() const**

        Returns true if the type of the current element is an IEEE 754 single-
        precision floating point (that is, if **type** () returns
        **QCborStreamReader::Float** ). If this function returns true, you may
        call **toFloat** () to read that data.

        **See also** **type** (), **toFloat** (), **isFloat16** (), and
        **isDouble** ().
        """
        ...

    def isFloat16(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isFloat16

        **bool QCborStreamReader::isFloat16() const**

        Returns true if the type of the current element is an IEEE 754 half-
        precision floating point (that is, if **type** () returns
        **QCborStreamReader::Float16** ). If this function returns true, you may
        call **toFloat16** () to read that data.

        **See also** **type** (), **toFloat16** (), **isFloat** (), and
        **isDouble** ().
        """
        ...

    @typing.overload
    def isSimpleType(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isSimpleType

        **bool QCborStreamReader::isSimpleType() const**

        Returns true if the type of the current element is any CBOR simple type,
        including a boolean value (true and false) as well as null and
        undefined. To find out which simple type this is, call **toSimpleType**
        (). Alternatively, to test for one specific simple type, call the
        overload that takes a **QCborSimpleType**  parameter.

        CBOR simple types are types that do not carry extra value. There are 255
        possibilities, but there are currently only four values that have
        defined meaning. Code is not expected to cope with unknown simple types
        and may simply discard the stream as invalid if it finds an unknown one.

        **See also** **QCborSimpleType** , **type** (), **isSimpleType**
        (QCborSimpleType), and **toSimpleType** ().
        """
        ...

    @typing.overload
    def isSimpleType(self, st: QCborSimpleType) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isSimpleType-1

        **bool QCborStreamReader::isSimpleType(QCborSimpleType st ) const**

        Returns true if the type of the current element is the simple type
        **st** , false otherwise. If this function returns true, then
        **toSimpleType** () will return **st**.

        CBOR simple types are types that do not carry extra value. There are 255
        possibilities, but there are currently only four values that have
        defined meaning. Code is not expected to cope with unknown simple types
        and may simply discard the stream as invalid if it finds an unknown one.

        **See also** **QCborSimpleType** , **type** (), **isSimpleType** (), and
        **toSimpleType** ().
        """
        ...

    def isTag(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isTag

        **bool QCborStreamReader::isTag() const**

        Returns true if the type of the current element is a CBOR tag (that is,
        if **type** () returns **QCborStreamReader::Tag** ). If this function
        returns true, you may call **toTag** () to read that data.

        **See also** **type** () and **toTag** ().
        """
        ...

    def isMap(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isMap

        **bool QCborStreamReader::isMap() const**

        Returns true if the type of the current element is a map (that is, if
        **type** () returns **QCborStreamReader::Map** ). If this function
        returns true, you may call **enterContainer** () to begin parsing that
        container.

        When the current element is a map, you may also call **isLengthKnown**
        () to find out if the map's size is explicit in the CBOR stream. If it
        is, that size can be obtained by calling **length** ().

        The following example pre-allocates a QVariantMap given the map's size
        for more efficient decoding:

        QVariantMap populateFromCbor(**QCborStreamReader**  &reader)
               {
        QVariantMap map;
                   if (reader.isLengthKnown())
        map.reserve(reader.length());

                   reader.enterContainer();
        while (reader.lastError() == **QCborError** ::NoError &&
        reader.hasNext()) {
                       **QString**  key =
        readElementAsString(reader);
                       map.insert(key,
        readOneElement(reader));
                   }
                   if (reader.lastError()
        == **QCborError** ::NoError)
                       reader.leaveContainer();
        }

        The example above uses a function called `readElementAsString` to read
        the map's keys and obtain a string. That is because CBOR maps may
        contain any type as keys, not just strings. User code needs to either
        perform this conversion, reject non-string keys, or instead use a
        different container besides **QVariantMap**  and **QVariantHash** . For
        example, if the map is expected to contain integer keys, which is
        recommended as it reduces stream size and parsing, the correct container
        would be `\\l{QMap}<int, QVariant>` or `\\l{QHash}<int, QVariant>`.

        **Note:** The code above does not validate that the length is a sensible
        value. If the input stream reports that the length is 1 billion
        elements, the above function will try to allocate some 24 GB or more of
        RAM, which can lead to a crash.

        **See also** **type** (), **isArray** (), **isLengthKnown** (),
        **length** (), **enterContainer** (), and **leaveContainer** ().
        """
        ...

    def isArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isArray

        **bool QCborStreamReader::isArray() const**

        Returns true if the type of the current element is an array (that is, if
        **type** () returns **QCborStreamReader::Array** ). If this function
        returns true, you may call **enterContainer** () to begin parsing that
        container.

        When the current element is an array, you may also call
        **isLengthKnown** () to find out if the array's size is explicit in the
        CBOR stream. If it is, that size can be obtained by calling **length**
        ().

        The following example pre-allocates a QVariantList given the array's
        size for more efficient decoding:

        QVariantList populateFromCbor(**QCborStreamReader**  &reader)
               {
        QVariantList list;
                   if (reader.isLengthKnown())
        list.reserve(reader.length());

                   reader.enterContainer();
        while (reader.lastError() == **QCborError** ::NoError &&
        reader.hasNext())
                       list.append(readOneElement(reader));
        if (reader.lastError() == **QCborError** ::NoError)
        reader.leaveContainer();
               }

        **Note:** The code above does not validate that the length is a sensible
        value. If the input stream reports that the length is 1 billion
        elements, the above function will try to allocate some 16 GB or more of
        RAM, which can lead to a crash.

        **See also** **type** (), **isMap** (), **isLengthKnown** (), **length**
        (), **enterContainer** (), and **leaveContainer** ().
        """
        ...

    def isString(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isString

        **bool QCborStreamReader::isString() const**

        Returns true if the type of the current element is a text string (that
        is, if **type** () returns **QCborStreamReader::String** ). If this
        function returns true, you may call **readString** () to read that data.

        **See also** **type** (), **readString** (), and **isByteArray** ().
        """
        ...

    def isByteArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isByteArray

        **bool QCborStreamReader::isByteArray() const**

        Returns true if the type of the current element is a byte array (that
        is, if **type** () returns **QCborStreamReader::ByteArray** ). If this
        function returns true, you may call **readByteArray** () to read that
        data.

        **See also** **type** (), **readByteArray** (), and **isString** ().
        """
        ...

    def isInteger(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isInteger

        **bool QCborStreamReader::isInteger() const**

        Returns true if the type of the current element is either an unsigned
        integer or a negative one (that is, if **type** () returns
        **QCborStreamReader::UnsignedInteger**  or
        **QCborStreamReader::NegativeInteger** ). If this function returns true,
        you may call **toInteger** () to read that value.

        **See also** **type** (), **toInteger** (), **toUnsignedInteger** (),
        **toNegativeInteger** (), **isUnsignedInteger** (), and
        **isNegativeInteger** ().
        """
        ...

    def isNegativeInteger(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isNegativeInteger

        **bool QCborStreamReader::isNegativeInteger() const**

        Returns true if the type of the current element is a negative integer
        (that is if **type** () returns **QCborStreamReader::NegativeInteger**
        ). If this function returns true, you may call **toNegativeInteger** ()
        or **toInteger** () to read that value.

        **See also** **type** (), **toNegativeInteger** (), **toInteger** (),
        **isInteger** (), and **isUnsignedInteger** ().
        """
        ...

    def isUnsignedInteger(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isUnsignedInteger

        **bool QCborStreamReader::isUnsignedInteger() const**

        Returns true if the type of the current element is an unsigned integer
        (that is if **type** () returns **QCborStreamReader::UnsignedInteger**
        ). If this function returns true, you may call **toUnsignedInteger** ()
        or **toInteger** () to read that value.

        **See also** **type** (), **toUnsignedInteger** (), **toInteger** (),
        **isInteger** (), and **isNegativeInteger** ().
        """
        ...

    def type(self) -> "QCborStreamReader.Type":
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#type

        **QCborStreamReader::Type QCborStreamReader::type() const**

        Returns the type of the current element. It is one of the valid types or
        Invalid.

        **See also** **isValid** (), **isUnsignedInteger** (),
        **isNegativeInteger** (), **isInteger** (), **isByteArray** (),
        **isString** (), **isArray** (), **isMap** (), **isTag** (),
        **isSimpleType** (), **isBool** (), **isFalse** (), **isTrue** (),
        **isNull** (), **isUndefined** (), **isFloat16** (), **isFloat** (), and
        **isDouble** ().
        """
        ...

    def next(self, maxRecursion: int = ...) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#next

        **bool QCborStreamReader::next(int maxRecursion = 10000)**

        Advance the CBOR stream decoding one element. You should usually call
        this function when parsing fixed-width basic elements (that is,
        integers, simple values, tags and floating point values). But this
        function can be called when the current item is a string, array or map
        too and it will skip over that entire element, including all contained
        elements.

        This function returns true if advancing was successful, false otherwise.
        It may fail if the stream is corrupt, incomplete or if the nesting level
        of arrays and maps exceeds **maxRecursion**. Calling this function when
        **hasNext** () has returned false is also an error. If this function
        returns false, **lastError** () will return the error code detailing
        what the failure was.

        **See also** **lastError** (), **isValid** (), and **hasNext** ().
        """
        ...

    def hasNext(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#hasNext

        **bool QCborStreamReader::hasNext() const**

        Returns true if there are more items to be decoded in the current
        container or false of we've reached its end. If we're parsing the root
        element, hasNext() returning false indicates the parsing is complete;
        otherwise, if the container depth is non-zero, then the outer code needs
        to call **leaveContainer** ().

        **See also** **parentContainerType** (), **containerDepth** (), and
        **leaveContainer** ().
        """
        ...

    def parentContainerType(self) -> "QCborStreamReader.Type":
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#parentContainerType

        **QCborStreamReader::Type QCborStreamReader::parentContainerType()
        const**

        Returns either **QCborStreamReader::Array**  or
        **QCborStreamReader::Map** , indicating whether the container that
        contains the current item was an array or map, respectively. If we're
        currently parsing the root element, this function returns
        **QCborStreamReader::Invalid** .

        **See also** **containerDepth** () and **enterContainer** ().
        """
        ...

    def containerDepth(self) -> int:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#containerDepth

        **int QCborStreamReader::containerDepth() const**

        Returns the number of containers that this stream has entered with
        **enterContainer** () but not yet left.

        **See also** **enterContainer** () and **leaveContainer** ().
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#isValid

        **bool QCborStreamReader::isValid() const**

        Returns true if the current element is valid, false otherwise. The
        current element may be invalid if there was a decoding error or we've
        just parsed the last element in an array or map.

        **Note:** This function is not the opposite of **isNull** (). Null is a
        normal CBOR type that must be handled by the application.

        **See also** **type** () and **isInvalid** ().
        """
        ...

    def currentOffset(self) -> int:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#currentOffset

        **qint64 QCborStreamReader::currentOffset() const**

        Returns the offset in the input stream of the item currently being
        decoded. The current offset is the number of decoded bytes so far only
        if the source data is a **QByteArray**  or it is a **QIODevice**  that
        was positioned at its beginning when decoding started.

        **See also** **reset** (), **clear** (), and **device** ().
        """
        ...

    def lastError(self) -> QCborError:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#lastError

        **QCborError QCborStreamReader::lastError()**

        Returns the last error in decoding the stream, if any. If no error was
        encountered, this returns an **QCborError::NoError** .

        **See also** **isValid** ().
        """
        ...

    def reset(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#reset

        **void QCborStreamReader::reset()**

        Resets the source back to the beginning and clears the decoder state. If
        the source data was a **QByteArray** , **QCborStreamReader**  will
        restart from the beginning of the array.

        If the source data is a **QIODevice** , this function will call
        **QIODevice::reset** (), which will seek to byte position 0. If the CBOR
        stream is not found at the beginning of the device (e.g., beginning of a
        file), then this function will likely do the wrong thing. Instead,
        position the **QIODevice**  to the right offset and call **setDevice**
        ().

        **See also** **clear** () and **setDevice** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#clear

        **void QCborStreamReader::clear()**

        Clears the decoder state and resets the input source data to an empty
        byte array. After this function is called, **QCborStreamReader**  will
        be indicating an error parsing.

        Call **addData** () to add more data to be parsed.

        **See also** **reset** () and **setDevice** ().
        """
        ...

    def reparse(self) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#reparse

        **void QCborStreamReader::reparse()**

        Reparses the current element. This function must be called when more
        data becomes available in the source **QIODevice**  after parsing failed
        due to reaching the end of the input data before the end of the CBOR
        stream.

        When reading from QByteArray(), the **addData** () function
        automatically calls this function. Calling it when the reading had not
        failed is a no-op.
        """
        ...

    def addData(self, data: QByteArray) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#addData

        **void QCborStreamReader::addData(const QByteArray & data )**

        Adds **data** to the CBOR stream and reparses the current element. This
        function is useful if the end of the data was previously reached while
        processing the stream, but now more data is available.
        """
        ...

    def device(self) -> QIODevice:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#device

        **QIODevice *QCborStreamReader::device() const**

        Returns the **QIODevice**  that was set with either **setDevice** () or
        the **QCborStreamReader**  constructor. If this object was reading from
        a **QByteArray** , this function returns nullptr instead.

        **See also** **setDevice** ().
        """
        ...

    def setDevice(self, device: QIODevice) -> None:
        """
        https://doc.qt.io/qt-6/qcborstreamreader.html#setDevice

        **void QCborStreamReader::setDevice(QIODevice * device )**

        Sets the source of data to **device** , resetting the decoder to its
        initial state.

        **See also** **device** ().
        """
        ...
